@@ -3,7 +3,7 @@ this_week <-
            part = getOption("timeperiodsR.parts"),
            week_start = 1) {
     
-    if ( ! "Date" %in% class(x) ) {
+    if ( ! inherits(x, "Date") ) {
       x <- as.Date(x)
     }
     
